/**
 * Get env settings.
 * @function apemanenv
 * @param {string} [dirname='env'] - Directory name with contains env data.
 * @param {object} options - Optional settings.
 * @returns {object} - Env data.
 */

'use strict'

const load = require('./load')
const override = require('./override')
const evaluate = require('./evaluate')
const print = require('./print')

const debug = require('debug')('apeman:env')

/** @lends apemanenv */
function apemanenv (dirname, options = {}) {
  debug(`NODE_ENV: ${process.env.NODE_ENV}`)

  let configs = load(dirname || './env')

  configs = evaluate(configs, options.vars || {})

  if (options.overridable) {
    configs = override(configs, process.env)
  }

  function env (name) {
    if (configs.hasOwnProperty(name)) {
      return configs[ name ]
    }
    throw new Error('Unknown name: ' + name)
  }

  // noinspection Eslint
  env.__proto__ = Object.assign(new Function(), {
    src: dirname,
    print: function printEnv () {
      print(env)
    },
    toJSON () {
      return Object.assign({}, configs)
    }
  })

  Object.assign(env, configs)
  Object.keys(env).forEach((key) => {
    debug(`${key}: ${JSON.stringify(env[ key ])}`)
  })
  return env
}

module.exports = apemanenv
