/**
 * @function override
 */
'use strict'

const objnest = require('objnest')
const colorprint = require('colorprint')
const stringcase = require('stringcase')
const colors = colorprint.colors

/** @lends override */
function override (src, overriding) {
  let data = objnest.flatten(src)

  let overridingKeys = Object.keys(overriding || {})
  let overridden = {}
  Object.keys(data || {}).forEach((key) => {
    let overridingKey = stringcase.snakecase(key.trim().toLowerCase()).toUpperCase()
    let hit = !!~overridingKeys.indexOf(overridingKey)
    if (hit) {
      overridden[ key ] = overridingKey
      data[ key ] = overriding[ overridingKey ]
    }
  })

  let overriddenKeys = Object.keys(overridden)
  if (overriddenKeys.length > 0) {
    colorprint.debug('[apemanenv] Override env:')
    overriddenKeys.forEach((key) => {
      let msg = `\t ${colors.black.bold(overridden[ key ])} -> ${key}`
      colorprint.debug(msg)
    })
    colorprint.debug('')
  }

  return objnest.expand(data)
}

module.exports = override
